sort list on is_primary rather than interface_id. this is guaranteed to have
authorStephen Soltesz <soltesz@cs.princeton.edu>
Mon, 8 Jun 2009 17:42:27 +0000 (17:42 +0000)
committerStephen Soltesz <soltesz@cs.princeton.edu>
Mon, 8 Jun 2009 17:42:27 +0000 (17:42 +0000)
the primary interface first.

plnet.py

index 1c92123..84b0791 100755 (executable)
--- a/plnet.py
+++ b/plnet.py
@@ -42,17 +42,18 @@ def InitInterfaces(logger, plc, data, root="", files_only=False, program="NodeMa
     # returned.  Because 'interface'is decremented as each interface is processed,
     # by the time is_primary=True (primary) interface is reached, the device
     # "eth%s" % interface, is not eth0.  But, something like eth-4, or eth-12.
# This code sorts the interfaces, implicitly placing the primary (first created)
# interface first.  There is a lot of room for improvement to how this
     # script handles interfaces and how it chooses the primary interface.
     def compare_by (fieldname):
         def compare_two_dicts (a, b):
             return cmp(a[fieldname], b[fieldname])
         return compare_two_dicts
-    if version == 4.3:
-        networks.sort( compare_by('interface_id') )
-    else:
-        networks.sort( compare_by('nodenetwork_id') )
+
+    # NOTE: by sorting on 'is_primary' and then reversing (since False is sorted
+    # before True) all 'is_primary' interfaces are at the beginning of the list.
+    networks.sort( compare_by('is_primary') )
+    networks.reverse()
 
     for network in networks:
        logger.verbose('net:InitInterfaces interface %d: %s'%(interface,network))
@@ -42,17 +42,18 @@ def InitInterfaces(logger, plc, data, root="", files_only=False, program="NodeMa
     # by the time is_primary=True (primary) interface is reached, the device
     # "eth%s" % interface, is not eth0.  But, something like eth-4, or eth-12.
-    # This code sorts the interfaces, implicitly placing the primary (first created)
-    # interface first.  There is a lot of room for improvement to how this
+    # This code sorts the interfaces, placing is_primary=True interfaces first.  
+    # There is a lot of room for improvement to how this
     # script handles interfaces and how it chooses the primary interface.
     def compare_by (fieldname):